# Keeper Secrets Manager Python SDK

For more information see our official documentation page https://docs.keeper.io/secrets-manager/secrets-manager/developer-sdk-library/python-sdk

# Change Log

## 16.3.4

* Provide better exception messages when the config JSON file is not utf-8 encoded.